@@ -18,15 +18,15 @@ data_path = os.path.join(path_to_script, '../sample_data/jatra_5mm/')
 
 
 
-print 'im1: 2D dicom image with SimpleITK'
+print('im1: 2D dicom image with SimpleITK')
 im1 = sitk.ReadImage(os.path.join(path_to_script,"../sample_data/jatra_5mm/IM-0001-0005.dcm"))
 pimsh = sitk.Show(im1)
 import pdb; pdb.set_trace()
 
 #--------------------------------------------
-print 'im2: 3D dicom image readed with our DataReader and visualization with SimpleITK'
+print('im2: 3D dicom image readed with our DataReader and visualization with SimpleITK')
 dr = datareader.DataReader()
-data3d, metadata = dr.Get3DData(data_path)
+data3d, metadata = dr.Get3DData(data_path, dataplus_format=False)
 
 im2 = sitk.GetImageFromArray(data3d)
 sitk.Show(im2)
@@ -34,10 +34,10 @@ sitk.Show(im2)
 import pdb; pdb.set_trace()
 
 #--------------------------------------------
-print 'im3: 3D dicom image read and visualization with SimpleITK'
+print('im3: 3D dicom image read and visualization with SimpleITK')
 isr = sitk.ImageSeriesReader()
 seriesids = isr.GetGDCMSeriesIDs(data_path)
-print seriesids
+print(seriesids)
 #dcmnames = isr.GetGDCMSeriesFileNames(data_path )
 dcmnames = isr.GetGDCMSeriesFileNames(data_path, seriesids[0], True, True, True, True)
 isr.SetFileNames(dcmnames)
