@@ -279,11 +279,11 @@ def read_data_orig_and_seg(inputdata, i):
     reader = datareader.DataReader()
     data3d_a_path = os.path.join(inputdata['basedir'],
                                  inputdata['data'][i]['sliverseg'])
-    data3d_a, metadata_a = reader.Get3DData(data3d_a_path)
+    data3d_a, metadata_a = reader.Get3DData(data3d_a_path, dataplus_format=False)
 
     data3d_b_path = os.path.join(inputdata['basedir'],
                                  inputdata['data'][i]['sliverorig'])
-    data3d_b, metadata_b = reader.Get3DData(data3d_b_path)
+    data3d_b, metadata_b = reader.Get3DData(data3d_b_path, dataplus_format=False)
 
     # import pdb; pdb.set_trace()
     data3d_seg = (data3d_a > 0).astype(np.int8)
@@ -411,9 +411,9 @@ def save_labels(
 def norm_voxelsize(data3d_orig, data3d_seg, voxelsize_mm,
                    working_voxelsize_mm):
 
-    data3d_orig_res = qmisc.resize_to_mm(data3d_orig,
+    data3d_orig_res = io3d.misc.resize_to_mm(data3d_orig,
                                          voxelsize_mm, working_voxelsize_mm)
-    data3d_seg_res = qmisc.resize_to_mm(data3d_seg,
+    data3d_seg_res = io3d.misc.resize_to_mm(data3d_seg,
                                         voxelsize_mm, working_voxelsize_mm)
 
     return data3d_orig_res, data3d_seg_res
@@ -535,7 +535,7 @@ def one_exp_set_testing(
                                              labels_lin)
 
         if use_voxelsize_norm:
-            segmentation = qmisc.resize_to_shape(
+            segmentation = io3d.misc.resize_to_shape(
                 segmentation,
                 data3d_orig_orig.shape)
 # @TODO změnil jsem to. Už zde není ukazatel na klasifikátor, ale přímo
@@ -570,8 +570,8 @@ def one_exp_set_for_whole_dataset(
         visualization=False):
     fvall = []
     # fv_tiles = []
-    print "classif_fcn ", classif_fcn_plus_params
-    print "feature_fcn ", feature_fcn_plus_params
+    print("classif_fcn ", classif_fcn_plus_params)
+    print("feature_fcn ", feature_fcn_plus_params)
     clf = one_exp_set_training(
         training_yaml, tile_shape,
         feature_fcn_plus_params,
@@ -626,7 +626,7 @@ def experiment(training_yaml_path, testing_yaml_path,  featers_plus_classifs,
 
         result = {'params': str(fpc), 'fvall': fvall}
         results.append(result)
-        print results
+        print(results)
 
     return results
 
@@ -634,7 +634,7 @@ def experiment(training_yaml_path, testing_yaml_path,  featers_plus_classifs,
 def prepared_classifiers_by_string(names):
     from sklearn import svm
     from sklearn.naive_bayes import GaussianNB  # noqa
-    from sklearn.mixture import GMM  # noqa
+    # from sklearn.mixture import GMM  # noqa
     from sklearn import tree  # noqa
     from sklearn.ensemble import RandomForestClassifier, AdaBoostClassifier  # noqa
     from sklearn.lda import LDA  # noqa
@@ -740,7 +740,7 @@ def main():
     # training_yaml_path = args.training_yaml_path
     # testing_yaml_path = args.testing_yaml_path
     if args.testing_yaml_path is None:
-        print 'testing is same as training'
+        print('testing is same as training')
         args.testing_yaml_path = args.training_yaml_path
 
     # write_csv(fvall)
