@@ -1,10 +1,15 @@
+from __future__ import absolute_import
 __all__ = ['organ_segmentation']
 #, 'qmisc', 'misc', 'experiments',
            #'support_structure_segmentation']
-__version__ = "1.9.2"
+__version__ = "1.15.0"
 
-import organ_segmentation
-from main import lisa_main
+import sys
+import os.path as op
+sys.path.insert(0, op.expanduser(r"~/projects/imtools/"))
+sys.path.insert(0, op.expanduser(r"~/projects/seededitorqt/"))
+from . import organ_segmentation
+from .main import lisa_main
 # import qmisc
 # import misc
 # import experiments
