@@ -1,3 +1,5 @@
 # This is because we want to draw splash screen before time-consuming imports
-from main import lisa_main
+from lisa.main import lisa_main
+# from .main import lisa_main
+# import main
 lisa_main()
