@@ -19,11 +19,17 @@ import sys
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
+import sys
+if sys.version_info.major == 2:
+    from PyQt4.Qt import QString
+else:
+    Qstring = str
+
 
 class LogEntryModel(QAbstractListModel):
     def __init__(self, logfile, parent=None):
         super(LogEntryModel, self).__init__(parent)
-        print logfile
+        print(logfile)
         self.parent = parent
         self.entries = None
         self.slurp(logfile)
@@ -86,7 +92,7 @@ class LogViewerForm(QDialog):
 
 
     def update_log(self):
-        print 'file changed'
+        print('file changed')
         self.list_model.slurp(self.list_model.logfile)
         self.list_view.updateGeometries()
         self.list_view.update()
