@@ -13,6 +13,14 @@
 import logging
 
 logger = logging.getLogger(__name__)
+import os.path
+import sys
+path_to_script = os.path.dirname(os.path.abspath(__file__))
+pth = os.path.join(path_to_script, "../../seededitorqt/")
+sys.path.insert(0, pth)
+pth = os.path.join(path_to_script, "../../imtools/")
+sys.path.insert(0, pth)
+
 import argparse
 
 def lisa_main():
@@ -25,12 +33,18 @@ def lisa_main():
     parser.add_argument(
         '-ni', '--no_interactivity', action='store_true',
         help='run in no interactivity mode, seeds must be defined')
+    parser.add_argument(
+        '--autolisa',
+        action='store_true',
+        help='run autolisa in dir',
+        default=False
+    )
+    knownargs, unknownargs = parser.parse_known_args()
     # Read alternative config file. First is loaded default config. Then user
     # config in lisa_data directory. After that is readed config defined by
     # --configfile parameter
-    knownargs, unknownargs = parser.parse_known_args()
 
-    if knownargs.no_interactivity:
+    if knownargs.no_interactivity or knownargs.autolisa:
         import organ_segmentation
         organ_segmentation.main()
     else:
@@ -41,10 +55,11 @@ def lisa_main():
         from PyQt4.QtGui import QApplication
         app = QApplication(sys.argv)
         # Create and display the splash screen
-        import splash_screen
+        from . import splash_screen
         splash = splash_screen.splash_screen(app)
-        import organ_segmentation
+        from . import organ_segmentation
         organ_segmentation.main(app, splash)
 
+
 if __name__ == "__main__":
     lisa_main()
\ No newline at end of file
