@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 import os
 import sys
 import os.path as op
-sys.path.append(op.join(op.dirname(os.path.abspath(__file__)), "../../pysegbase/"))
+sys.path.append(op.join(op.dirname(os.path.abspath(__file__)), "../../imcut/"))
 import argparse
 import glob
 import traceback
@@ -47,7 +47,7 @@ def add_fv_extern_into_modelparams(modelparams):
                 modelparams['fv_extern'] = intensity_localization_2steps_fv
             elif fv_extern_str == "near_blur_intensity_localization_fv":
                 modelparams['fv_extern'] = near_blur_intensity_localization_fv
-                print "blur intensity"
+                print("blur intensity")
             elif fv_extern_str == "with_ribs_fv":
                 modelparams['fv_extern'] = with_ribs_fv
                 logger.debug('with_ribs_fv used')
@@ -58,7 +58,7 @@ def add_fv_extern_into_modelparams(modelparams):
 def with_ribs_fv(data3dr, voxelsize_mm, seeds=None, unique_cls=None):        # scale
     """
     Feature vector use intensity and body_navigation module with ribs.
-    Implemented by T. Kolar
+    Implemented by M Bulka
 
     :param data3dr:
     :param voxelsize_mm:
@@ -310,7 +310,7 @@ def intensity_localization_2steps_fv(data3dr, voxelsize_mm, seeds=None, unique_c
 
 class ModelTrainer():
     def __init__(self, feature_function=None, modelparams={}):
-        from pysegbase import pycut
+        from imcut import pycut
         self.working_voxelsize_mm = [1.5, 1.5, 1.5]
         self.data=None
         self.target=None
@@ -364,21 +364,21 @@ class ModelTrainer():
         self.cl.fit(self.data, self.target)
 
     def predict(self, data3d, voxelsize_mm):
-        data3dr = qmisc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
+        data3dr = io3d.misc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
         fv = self._fv(data3dr)
 #         print "shape predict ", fv.shape,
         pred = self.cl.predict(fv)
 #         print "predict ", pred.shape,
-        return qmisc.resize_to_shape(pred.reshape(data3dr.shape), data3d.shape)
+        return io3d.misc.resize_to_shape(pred.reshape(data3dr.shape), data3d.shape)
 
     def scores(self, data3d, voxelsize_mm):
-        data3dr = qmisc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
+        data3dr = io3d.misc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
         fv = self._fv(data3dr)
 #         print "shape predict ", fv.shape,
         scoreslin = self.cl.scores(fv)
         scores = {}
         for key in scoreslin:
-            scores[key] = qmisc.resize_to_shape(scoreslin[key].reshape(data3dr.shape), data3d.shape)
+            scores[key] = io3d.misc.resize_to_shape(scoreslin[key].reshape(data3dr.shape), data3d.shape)
 
         return scores
 
@@ -387,8 +387,8 @@ class ModelTrainer():
         pass
 
     def add_train_data(self, data3d, segmentation, voxelsize_mm):
-        data3dr = qmisc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
-        segmentationr = qmisc.resize_to_shape(segmentation, data3dr.shape)
+        data3dr = io3d.misc.resize_to_mm(data3d, voxelsize_mm, self.working_voxelsize_mm)
+        segmentationr = io3d.misc.resize_to_shape(segmentation, data3dr.shape)
 
         logger.debug(str(np.unique(segmentationr)))
         logger.debug(str(data3dr.shape) + str(segmentationr.shape))
@@ -438,13 +438,13 @@ class ModelTrainer():
         if len(orig_fnames) == 0:
             logger.warning("No file found in path:\n{}".format(reference_dir + orig_pattern))
 
-        print (ref_fnames)
+        print(ref_fnames)
 
         for oname, rname in zip(orig_fnames, ref_fnames):
             logger.debug(oname)
-            data3d_orig, metadata = io3d.datareader.read(oname)
+            data3d_orig, metadata = io3d.datareader.read(oname, dataplus_format=False)
             vs_mm1 = metadata['voxelsize_mm']
-            data3d_seg, metadata = io3d.datareader.read(rname)
+            data3d_seg, metadata = io3d.datareader.read(rname, dataplus_format=False)
             vs_mm = metadata['voxelsize_mm']
             if segmentation_key is not None:
                 data3d_seg = metadata['segmentation']
@@ -469,7 +469,7 @@ class ModelTrainer():
                 self.add_train_data(data3d_orig, data3d_seg, voxelsize_mm=vs_mm)
             except:
                 traceback.print_exc()
-                print "problem - liver model"
+                print("problem - liver model")
                 pass
                 # fvhn = copy.deepcopy(fvh)
                 #fhs_list.append(fvh)
@@ -477,7 +477,7 @@ class ModelTrainer():
         self.fit()
 
         output_file = op.expanduser(output_file)
-        print "Saved into: ", output_file
+        print("Saved into: ", output_file)
         self.cl.save(output_file)
 
 
@@ -533,7 +533,7 @@ def model_score_from_sliver_data(
     :return:
     """
     import pandas as pd
-    from pysegbase import pycut
+    from imcut import pycut
     import sed3
     import matplotlib.pyplot as plt
 
@@ -549,10 +549,10 @@ def model_score_from_sliver_data(
     evaluation_all = []
 
     for oname, rname in zip(orig_fnames, ref_fnames):
-        print oname
-        data3d_orig, metadata = io3d.datareader.read(oname)
+        print(oname)
+        data3d_orig, metadata = io3d.datareader.read(oname, dataplus_format=False)
         vs_mm1 = metadata['voxelsize_mm']
-        data3d_seg, metadata = io3d.datareader.read(rname)
+        data3d_seg, metadata = io3d.datareader.read(rname, dataplus_format=False)
         vs_mm = metadata['voxelsize_mm']
 
         mdl = pycut.Model(modelparams=modelparams)
@@ -561,7 +561,7 @@ def model_score_from_sliver_data(
 
 
         vs_mmr = [1.5, 1.5, 1.5]
-        data3dr = qmisc.resize_to_mm(data3d_orig, vs_mm1, vs_mmr)
+        data3dr = io3d.misc.resize_to_mm(data3d_orig, vs_mm1, vs_mmr)
         lik1 = mdl.likelihood_from_image(data3dr, vs_mmr, 0)
         lik2 = mdl.likelihood_from_image(data3dr, vs_mmr, 1)
 
@@ -576,12 +576,12 @@ def model_score_from_sliver_data(
         #     seg = (lik1).astype(np.uint8)
 
 
-            seg_orig = qmisc.resize_to_shape(seg, data3d_orig.shape)
-        #       seg_orig = qmisc.resize_to_shape(seg, data3d_orig.shape)
+            seg_orig = io3d.misc.resize_to_shape(seg, data3d_orig.shape)
+        #       seg_orig = io3d.misc.resize_to_shape(seg, data3d_orig.shape)
             if show:
                 plt.figure(figsize = (15,15))
                 sed3.show_slices(data3d_orig , seg_orig, show=False, slice_step=20)
-                # likres = qmisc.resize_to_shape(lik1, data3d_orig.shape)
+                # likres = io3d.misc.resize_to_shape(lik1, data3d_orig.shape)
                 # sed3.show_slices(likres , seg_orig, show=False, slice_step=20)
 
             import re
