@@ -28,8 +28,6 @@ except:
     print('dicom2fem not found')
     # logger.warning('dicom2fem not found')
     from seg2mesh import gen_mesh_from_voxels, smooth_mesh
-import misc
-import viewer
 
 
 def showSegmentation(
@@ -60,7 +58,7 @@ def showSegmentation(
     _stats(segmentation)
     if resize_mm is not None:
         logger.debug("resize begin")
-        print "resize"
+        print("resize")
         new_voxelsize_mm = np.asarray([resize_mm, resize_mm, resize_mm])
         import imtools
         segmentation = imtools.misc.resize_to_mm(segmentation, voxelsize_mm=voxelsize_mm, new_voxelsize_mm=new_voxelsize_mm)
@@ -82,17 +80,18 @@ def showSegmentation(
         qt_app = QApplication(sys.argv)
         logger.debug("qapp constructed")
     if show:
+        import viewer
         view = viewer.QVTKViewer(vtk_file)
-        print ('show viewer')
+        print('show viewer')
         view.exec_()
 
     return labels
 
 def _stats(data):
-    print "stats"
+    print("stats")
     un = np.unique(data)
     for lab in un:
-        print lab, " : ", np.sum(data==lab)
+        print(lab, " : ", np.sum(data==lab))
 
 def main():
     logger = logging.getLogger()
