@@ -22,10 +22,10 @@ import sys
 import os.path
 
 path_to_script = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(os.path.join(path_to_script, "../src/"))
-sys.path.append(os.path.join(path_to_script, "../extern/pyseg_base/src"))
-sys.path.append(os.path.join(path_to_script,
-                             "../extern/sed3/"))
+# sys.path.append(os.path.join(path_to_script, "../src/"))
+# sys.path.append(os.path.join(path_to_script, "../extern/pyseg_base/src"))
+# sys.path.append(os.path.join(path_to_script,
+#                              "../extern/sed3/"))
 # sys.path.append(os.path.join(path_to_script, "../extern/"))
 # import featurevector
 
@@ -49,8 +49,8 @@ import sed3
 import argparse
 
 # import segmentation
-import qmisc
-import misc
+from . import qmisc
+from . import misc
 # import organ_segmentation
 # import experiments
 from io3d import datareader
@@ -161,14 +161,14 @@ def eval_all_from_dataset_metadata(inputdata, visualization=False,
         reader = datareader.DataReader()
         data3d_a_path = os.path.join(inputdata['basedir'],
                                      inputdata['data'][i]['sliverseg'])
-        data3d_a, metadata_a = reader.Get3DData(data3d_a_path)
-        print "inputdata ", inputdata['data'][i].values()
+        data3d_a, metadata_a = reader.Get3DData(data3d_a_path, dataplus_format=False)
+        print("inputdata ", list(inputdata['data'][i].values()))
         try:
             # if there is defined overlay
-            data3d_a = reader.GetOverlay()[inputdata['data'][i][
+            data3d_a = reader.get_overlay()[inputdata['data'][i][
                 'overlay_number']]
             logger.info('overlay loaded')
-            print 'overlay loaded'
+            print('overlay loaded')
         except:
             logger.debug("overlay not loaded")
             pass
@@ -241,7 +241,7 @@ def eval_all_from_dataset_metadata(inputdata, visualization=False,
 
 
 def compare_volumes_boundingbox(vol1, vol2, voxelsize_mm):
-    import qmisc
+    from . import qmisc
 
     crinfo = qmisc.crinfo_from_specific_data(vol1, [20, 20, 20])
     vol1[
@@ -438,7 +438,12 @@ def write_csv(data, filename='20130812_liver_volumetry.csv'):
     logger.debug(filename)
     import csv
 
-    with open(filename, 'wb') as csvfile:
+    if sys.version_info.major == 2:
+        open_mode = "wb"
+    else:
+        open_mode = "w"
+    with open(filename, open_mode) as csvfile:
+    # with open(filename, 'wb') as csvfile:
         writer = csv.writer(
             csvfile,
             delimiter=';',
@@ -450,21 +455,35 @@ def write_csv(data, filename='20130812_liver_volumetry.csv'):
             writer.writerow([label] + data[label])
             # spamwriter.writerow(['Spam', 'Lovely Spam', 'Wonderful Spam'])
 
+def csv_example():
+    import csv
+    with open('eggs.csv', 'w', newline='') as csvfile:
+        spamwriter = csv.writer(csvfile, delimiter=' ',
+                                quotechar='|', quoting=csv.QUOTE_MINIMAL)
+        spamwriter.writerow(['Spam'] * 5 + ['Baked Beans'])
+        spamwriter.writerow(['Spam', 'Lovely Spam', 'Wonderful Spam'])
 
 def write_sum_to_csv(evaluation, writer):
     avg, var = make_sum(evaluation)
-    key = evaluation.keys()
-    writer.writerow([' - '] + key)
-    writer.writerow(['var'] + var)
-    writer.writerow(['avg'] + avg)
-    writer.writerow([])
+    key = list(evaluation.keys())
+    _write_row([' - '] + key, writer)
+    _write_row(['var'] + var, writer)
+    _write_row(['avg'] + avg, writer)
+    _write_row([], writer)
+
+def _write_row(row_list, writer):
+    row_list_utf8 = prepare_row(row_list)
+    writer.writerow(row_list_utf8)
+
+def prepare_row(row_list):
+    return row_list
 
 
 def sliver_overall_score_for_one_couple(score):
     """
     Computes overall score:
     """
-    score_list = score.values()
+    score_list = list(score.values())
     overall_score = np.average(np.array(score_list))
 
     return overall_score
@@ -474,7 +493,7 @@ def sliverScore(measure, metric_type):
     """
     deprecated name of sliver_score. Use new sliver_score() function.
     """
-    print "Deprecated function sliverScore(). Use sliver_score()."
+    print("Deprecated function sliverScore(). Use sliver_score().")
     return sliver_score(measure, metric_type)
 
 
@@ -581,7 +600,7 @@ def make_sum(evaluation):
             avgi = np.average(evaluation[key])
             vari = np.var(evaluation[key])
         except Exception:
-            print "problem with key: ", key
+            print("problem with key: ", key)
             # print evaluation[key]
         avg.append(avgi)
         var.append(vari)
