@@ -25,14 +25,14 @@ path_to_script = os.path.dirname(os.path.abspath(__file__))
 
 def submodule_update():
     # update submodules codes
-    print ('Updating submodules')
+    print('Updating submodules')
     try:
         # import pdb; pdb.set_trace()
         subprocess.call('git submodule update --init --recursive', shell=True)
         # subprocess.call('git submodule update --init --recursive')
 
     except:
-        print ('Probem with git submodules')
+        print('Probem with git submodules')
 
 
 def check_python_architecture(pythondir, target_arch_str):
@@ -41,7 +41,7 @@ def check_python_architecture(pythondir, target_arch_str):
     """
     pyth_str = subprocess.check_output(
         [pythondir + 'python', '-c',
-         'import platform; print platform.architecture()[0]'])
+         'import platform; print(platform.architecture()[0])'])
     if pyth_str[:2] != target_arch_str:
         raise Exception(
             "Wrong architecture of target python. Expected arch is"
@@ -99,19 +99,19 @@ def windows_install():
     # check correct python version
     if (sys.version_info[0:2] != pythonversion):
 
-        print ("Different python required \n installing python "
+        print("Different python required \n installing python "
                + str(pythonversion))
-        print (sys.version_info)
+        print(sys.version_info)
 
         local_file_name = 'tmp\python.msi'
         urllibr.urlretrieve(urlpython, local_file_name)
         a = "msiexec /i " + local_file_name
-        print (a)
+        print(a)
         subprocess.call(a)
 
         check_python_architecture(pythondir, target_arch_str)
 
-        print ("Please restart installer with new python")
+        print("Please restart installer with new python")
         subprocess.call(pythondir + "python.exe mysetup.py")
         return
     else:
@@ -131,7 +131,7 @@ def windows_install():
     subprocess.call(pythondir + "python.exe get-pip.py", cwd="./tmp/")
 
     # numpy, scipy, matplotlib, scikit-learn, cython
-    print ("numpy, scipy, matplotlib, scikit-learn, cython install")
+    print("numpy, scipy, matplotlib, scikit-learn, cython install")
     #import pdb; pdb.set_trace()
     try:
 
@@ -141,7 +141,7 @@ def windows_install():
             + " matplotlib cython nose",
             cwd="./tmp/")
     except:
-        print ("alternative installation ")
+        print("alternative installation ")
         download_and_run(urlnumpy, "./tmp/numpy.exe")
         download_and_run(urlscipy, "./tmp/scipy.exe")
         download_and_run(urlsklearn, "./tmp/sklearn.exe")
@@ -157,18 +157,18 @@ def windows_install():
 def windows_get_git():
 
     # instalace msys gitu
-    print ("MSYS Git install")
+    print("MSYS Git install")
     #import pdb; pdb.set_trace()
     download_and_run(url=urlmsysgit, local_file_name='./tmp/msysgit.exe')
 
 
 def windows_build_gco():
     # install MinGW
-    print ("MinGW install")
+    print("MinGW install")
     download_and_run(url=urlmingw, local_file_name='./tmp/mingw.exe')
 
     # install gco_python
-    print ("gco_python install")
+    print("gco_python install")
     # --- first we need gco_python source codes
     #try:
     #    os.mkdir("tmp/gco_python")
@@ -192,7 +192,7 @@ def windows_build_gco():
     datafile.extractall('./tmp/gco_python-master/gco_src')
 
     # --- now compile
-    print ("gco compilation")
+    print("gco compilation")
 
     # there is a bug in python mingw compiler with -mno-cygwin, so here is simple patch
 
@@ -212,9 +212,9 @@ def remove(local_file_name):
     try:
         os.remove(local_file_name)
     except Exception as e:
-        print ("Cannot remove file '" + local_file_name + "'. Please remove\
+        print("Cannot remove file '" + local_file_name + "'. Please remove\
         it manually.")
-        print (e)
+        print(e)
 
 
 def downzip(url, destination='./sample_data/'):
@@ -371,7 +371,7 @@ def file_copy_and_replace_lines(in_path, out_path):
         # coma on end makes no linebreak
         line = line.replace("@{LISA_PATH}", lisa_path)
         line = line.replace("@{CONDA_PATH}", conda_path)
-        print line
+        print(line)
 
 
 def make_icon():
@@ -397,8 +397,8 @@ def __make_icon_linux():
 
     in_path = os.path.join(path_to_script, "applications/lisa.desktop.in")
     in_path_ha = os.path.join(path_to_script, "applications/ha.desktop.in")
-    print "icon input path:"
-    print in_path, in_path_ha
+    print("icon input path:")
+    print(in_path, in_path_ha)
 
     home_path = os.path.expanduser('~')
 
@@ -407,7 +407,7 @@ def __make_icon_linux():
     elif os.path.exists(os.path.join(home_path, 'Plocha')):
         desktop_path = os.path.join(home_path, 'Plocha')
     else:
-        print "Cannot find desktop directory"
+        print("Cannot find desktop directory")
         desktop_path = None
 
     # copy desktop files to desktop
@@ -416,8 +416,8 @@ def __make_icon_linux():
         out_path_ha = os.path.join(desktop_path, "ha.desktop")
 
         # fi = fileinput.input(out_path, inplace=True)
-        print "icon output path:"
-        print out_path, out_path_ha
+        print("icon output path:")
+        print(out_path, out_path_ha)
         file_copy_and_replace_lines(in_path, out_path)
         file_copy_and_replace_lines(in_path_ha, out_path_ha)
 
@@ -429,13 +429,13 @@ def __make_icon_linux():
 
         out_path_ha = os.path.join(local_app_path, "ha.desktop")
 
-        print "icon output path:"
-        print out_path, out_path_ha
+        print("icon output path:")
+        print(out_path, out_path_ha)
         file_copy_and_replace_lines(in_path, out_path)
         file_copy_and_replace_lines(in_path_ha, out_path_ha)
 
     else:
-        print "Couldnt find $HOME/.local/share/applications/."
+        print("Couldnt find $HOME/.local/share/applications/.")
 
 
 def main():
