@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 
+import logging
+logger = logging.getLogger(__name__)
 
 # import funkcí z jiného adresáře
 import sys
@@ -19,12 +21,16 @@ from PyQt4.QtGui import QFileDialog, QApplication, QMainWindow
 
 import numpy as np
 
-import dicom
-dicom.debug(False)
+try:
+    import pydicom
+except ImportError as e:
+    import dicom as pydicom
+    logger.warning("Used dicom instead of pydicom")
+pydicom.config.debug(False)
 
 #
 import io3d
-import pysegbase.dcmreaddata as dcmr
+import io3d.dcmreaddata as dcmr
 import lisa.dataset
 
 class DicomReaderTest(unittest.TestCase):
@@ -38,10 +44,16 @@ class DicomReaderTest(unittest.TestCase):
 #        self.metadata = reader.get_metaData()
 
     def test_DicomReader_overlay(self):
+        import os.path as op
+        # sample_data_path = "~/data/medical/orig/sample_data/"
+        # sample_data_path = op.expanduser(sample_data_path)
+        # sample_data_path = io3d.datasets.join_path("medical/orig/sample_data/", get_root=True)
+        sample_data_path = io3d.datasets.join_path("medical", "orig", get_root=True)
         #import matplotlib.pyplot as plt
 
-        dcmdir = lisa.dataset.join_sdp('volumetrie/')
-        #dcmdir = '/home/mjirik/data/medical/data_orig/jatra-kma/jatra_5mm/'
+        # dcmdir = lisa.dataset.join_sdp('volumetrie/')
+        dcmdir = os.path.join(sample_data_path, 'volumetrie')
+        # dcmdir = '/home/mjirik/data/medical/data_orig/jatra-kma/jatra_5mm/'
         #self.data3d, self.metadata = dcmr.dcm_read_from_dir(self.dcmdir)
         reader = dcmr.DicomReader(dcmdir)
         overlay = reader.get_overlay()
@@ -49,19 +61,20 @@ class DicomReaderTest(unittest.TestCase):
         #plt.imshow(overlay[1][:,:,0])
         #plt.show()
 
-        self. assertEqual(overlay[1][0,200,200],1)
-        self. assertEqual(overlay[1][0,100,100],0)
+        self.assertEqual(overlay[1][0, 200, 200], 1)
+        self.assertEqual(overlay[1][0, 100, 100], 0)
+
     def test_read_volumetry_overlay_with_dicom_module(self):
         """
         pydicom module is used for load dicom data. Dicom overlay
         is saved on (60xx,3000) bit after bit. Data are decoded and
         each bit is stored as array element.
         """
-        import dicom
+        # import dicom
         # import sed3
         #import matplotlib.pyplot as plt
         dcmfile = lisa.dataset.join_sdp('volumetrie/volumetry_slice.DCM')
-        data = dicom.read_file(dcmfile)
+        data = pydicom.read_file(dcmfile)
 
 
 
@@ -75,19 +88,23 @@ class DicomReaderTest(unittest.TestCase):
         # and so on.
         dicom_tag1 = 0x6000 + 2*i_overlay
 
-        overlay_raw = data[dicom_tag1 ,0x3000].value
+        overlay_raw = data[dicom_tag1, 0x3000].value
 
         # On (60xx,0010) and (60xx,0011) is stored overlay size
-        rows = data[dicom_tag1,0x0010].value # rows = 512
-        cols = data[dicom_tag1,0x0011].value # cols = 512
+        rows = data[dicom_tag1, 0x0010].value # rows = 512
+        cols = data[dicom_tag1, 0x0011].value # cols = 512
 
         decoded_linear = np.zeros(len(overlay_raw)*n_bits)
 
         # Decoding data. Each bit is stored as array element
         for i in range(1,len(overlay_raw)):
-            for k in range (0,n_bits):
-                byte_as_int = ord(overlay_raw[i])
-                decoded_linear[i*n_bits + k] = (byte_as_int >> k) & 0b1
+            for k in range (0, n_bits):
+                one_byte = overlay_raw[i]
+                if sys.version_info.major == 2:
+                    byte_as_int = ord(one_byte)
+                else:
+                    byte_as_int = one_byte
+                decoded_linear[i * n_bits + k] = (byte_as_int >> k) & 0b1
 
         #overlay = np.array(pol)
 
@@ -125,7 +142,7 @@ class DicomReaderTest(unittest.TestCase):
         dcmdir = lisa.dataset.join_sdp('jatra_5mm')
         #dcmdir = '/home/mjirik/data/medical/data_orig/jatra-kma/jatra_5mm/'
         #self.data3d, self.metadata = dcmr.dcm_read_from_dir(self.dcmdir)
-        data3d, metadata = io3d.datareader.read(dcmdir)
+        data3d, metadata = io3d.datareader.read(dcmdir, dataplus_format=False)
 #slice size is 512x512
         self.assertEqual(data3d.shape[2],512)
 # voxelsize depth = 5 mm
