@@ -23,6 +23,7 @@ import lisa.volumetry_evaluation as ve
 import lisa
 import lisa.experiments
 import lisa.dataset
+from lisa.dataset import join_sdp
 
 
 # just test if everything is going ok
@@ -32,9 +33,6 @@ def speceval(vol1, vol2, vs):
     """
     return {'one': 1}
 
-def join_sdp(datapath):
-    return lisa.dataset.join_sdp(datapath)
-
 class ExperimentsTest(unittest.TestCase):
 
     def test_experiment_set_(self):
@@ -52,7 +50,7 @@ class ExperimentsTest(unittest.TestCase):
 
         # experiment_dir = join_sdp("exp_small2/")
 
-        sliver_reference_dir = join_sdp("exp/seg")
+        sliver_reference_dir = join_sdp("exp_small/seg")
 
 # this is setup for visualization
         markers = ['ks',
@@ -209,6 +207,7 @@ class ExperimentsTest(unittest.TestCase):
         conf_default = {
             'config_version': [1, 0, 0], 'working_voxelsize_mm': 2.0,
             'segmentation_smoothing': False,
+            "run_organ_segmentation": True,
             'segparams': {'pairwise_alpha_per_mm2': 50,
                           'return_only_object_with_seeds': True}
         }
