@@ -6,7 +6,8 @@
 import sys
 import os.path
 
-# path_to_script = os.path.dirname(os.path.abspath(__file__))
+# imcut_path =  os.path.join(path_to_script, "../../imcut/")
+# sys.path.insert(0, imcut_path)
 import unittest
 
 import numpy as np
@@ -14,8 +15,9 @@ from nose.plugins.attrib import attr
 
 
 from lisa import organ_segmentation
-import pysegbase.dcmreaddata as dcmr
+import imcut.dcmreaddata as dcmr
 import lisa.dataset
+import io3d.datasets
 
 
 # nosetests tests/organ_segmentation_test.py:OrganSegmentationTest.test_create_iparams # noqa
@@ -44,7 +46,7 @@ class OrganSegmentationTest(unittest.TestCase):
     def test_viewer_seeds(self):
 
         try:
-            from pysegbase.seed_editor_qt import QTSeedEditor
+            from imcut.seed_editor_qt import QTSeedEditor
         except:
             print("Deprecated of pyseg_base as submodule")
             from seed_editor_qt import QTSeedEditor
@@ -73,8 +75,7 @@ class OrganSegmentationTest(unittest.TestCase):
         """
         Interactive test uses dicom data for segmentation
         """
-        dcmdir = os.path.join(
-            lisa.dataset.sample_data_path(),
+        dcmdir = io3d.datasets.join_path(
             'matlab/examples/sample_data/DICOM/digest_article/'
         )
             # path_to_script,
@@ -83,14 +84,14 @@ class OrganSegmentationTest(unittest.TestCase):
             dcmdir, working_voxelsize_mm=4, manualroi=False)
 
 # manual seeds setting
-        print ("with left mouse button select some pixels of the brain")
-        print ("with right mouse button select some pixels of other tissues\
+        print("with left mouse button select some pixels of the brain")
+        print("with right mouse button select some pixels of other tissues\
 and background")
 
         oseg.interactivity()
 
         volume = oseg.get_segmented_volume_size_mm3()
-        print volume
+        print(volume)
 
         self.assertGreater(volume, 50000)
         self.assertLess(volume, 1200000)
@@ -113,12 +114,10 @@ and background")
         """
         Interactivity is stored to file
         """
-        dcmdir = os.path.join(
-            lisa.dataset.sample_data_path(),
-            'jatra_5mm')
+        dcmdir = io3d.datasets.join_path('jatra_5mm')
 
-        print "Interactive test: with left mouse button select liver, \
-            with right mouse button select other tissues"
+        print("Interactive test: with left mouse button select liver, \
+            with right mouse button select other tissues")
         # gcparams = {'pairwiseAlpha':10, 'use_boundary_penalties':True}
         segparams = {'pairwise_alpha_per': 3,
                      'use_boundary_penalties': True,
@@ -146,9 +145,9 @@ and background")
         Interactivity is stored to file
         """
         if self.verbose:
-            print "test_create_iparams"
+            print("test_create_iparams")
         import misc
-        dcmdir = os.path.join(lisa.dataset.sample_data_path(), 'jatra_5mm')
+        dcmdir = io3d.datasets.join_path('jatra_5mm')
             # path_to_script, './../sample_data/jatra_5mm')
 
         segparams = {'pairwiseAlpha': 20,
@@ -181,34 +180,11 @@ and background")
         pass
 
 # TODO finish this test
+    @attr("interactive")
     def test_synth_liver(self):
         params = {}
         self.synthetic_liver_template(params)
 
-    def synthetic_liver(self):
-        """
-        Create synthetic data. There is some liver and porta -like object.
-        """
-        # data
-        slab = {'none': 0, 'liver': 1, 'porta': 2}
-        voxelsize_mm = np.array([1.0, 1.0, 1.2])
-
-        segm = np.zeros([80, 256, 250], dtype=np.int16)
-
-        # liver
-        segm[30:60, 70:180, 40:190] = slab['liver']
-        # porta
-        segm[40:45, 120:130, 70:190] = slab['porta']
-        segm[40:45, 80:130, 100:110] = slab['porta']
-        segm[40:44, 120:170, 130:135] = slab['porta']
-
-        data3d = np.zeros(segm.shape)
-        data3d[segm == slab['liver']] = 146
-        data3d[segm == slab['porta']] = 206
-        noise = (np.random.normal(0, 10, segm.shape))  # .astype(np.int16)
-        data3d = (data3d + noise).astype(np.int16)
-        return data3d, segm, voxelsize_mm, slab
-
     def synthetic_liver_template(self, params):
         """
         Function uses organ_segmentation  for synthetic box object
@@ -217,12 +193,12 @@ and background")
         # dcmdir = os.path.join(path_to_script,'./../sample_data/matlab/examples/sample_data/DICOM/digest_article/') # noqa
 # data
 
-        data3d, segm, voxelsize_mm, slab = self.synthetic_liver()
+        data3d, segm, voxelsize_mm, slab, seeds_liver, seeds_porta = io3d.datasets.generate_synthetic_liver()
 
 # seeds
-        seeds = np.zeros(data3d.shape, np.int8)
-        seeds[40:55, 90:120, 70:110] = 1
-        seeds[30:45, 190:200, 40:90] = 2
+#         seeds = np.zeros(data3d.shape, np.int8)
+#         seeds[40:55, 90:120, 70:110] = 1
+#         seeds[30:45, 190:200, 40:90] = 2
 # [mm]  10 x 10 x 10        # voxelsize_mm = [1, 4, 3]
         metadata = {'voxelsize_mm': voxelsize_mm}
 
@@ -230,7 +206,7 @@ and background")
             None,
             data3d=data3d,
             metadata=metadata,
-            seeds=seeds,
+            seeds=seeds_liver,
             working_voxelsize_mm=5,
             manualroi=False,
             autocrop=False,
@@ -240,8 +216,19 @@ and background")
 
         oseg.ninteractivity()
 
-        volume = oseg.get_segmented_volume_size_mm3()
+        volume = oseg.get_segmented_volume_size_mm3("liver")
+        self.assertGreater(volume, 570000, "Liver volume should have proper size")
+        self.assertLess(volume, 640000, "Liver volume should have proper size")
+
         oseg.portalVeinSegmentation(interactivity=False, threshold=180)
+
+        volume_porta = oseg.get_segmented_volume_size_mm3("porta")
+        self.assertGreater(volume_porta, 9000, "Liver volume should have proper size")
+        self.assertLess(volume_porta, 11000, "Liver volume should have proper size")
+        # import sed3
+        # ed = sed3.sed3(data3d,
+        #                contour=(oseg.segmentation))
+        # ed.show()
         oseg.saveVesselTree('porta')
 
         # print '> 0 '
@@ -254,16 +241,10 @@ and background")
         # print oseg.voxelsize_mm
 
         # import pdb; pdb.set_trace()
-        # import sed3
-        # ed = sed3.sed3(data3d, seeds=seeds,
-        #                contour=(oseg.segmentation))
-        # ed.show()
         # import ipdb; ipdb.set_trace() #  noqa BREAKPOINT
 
         # mel by to být litr. tedy milion mm3
         # je to zvlastni. pro nekter verze knihoven je to 630, pro jine 580
-        self.assertGreater(volume, 570000)
-        self.assertLess(volume, 640000)
 
     def test_roi(self):
         """
@@ -313,17 +294,17 @@ and background")
         segmentation.
         """
         params = {'segmentation_smoothing': True}
-        self.box_segmentation_template(params)
+        self.box_segmentation_template(params, noise_sigma=4)
         # dcmdir = os.path.join(path_to_script,'./../sample_data/matlab/examples/sample_data/DICOM/digest_article/') # noqa
 
-    def box_segmentation_template(self, params):
+    def box_segmentation_template(self, params, noise_sigma=3):
         """
         Function uses organ_segmentation  for synthetic box object
         segmentation.
         """
         # dcmdir = os.path.join(path_to_script,'./../sample_data/matlab/examples/sample_data/DICOM/digest_article/') # noqa
 # data
-        img3d = np.random.rand(32, 64, 64) * 3
+        img3d = np.random.rand(32, 64, 64) * noise_sigma
         img3d[4:24, 12:32, 5:25] = img3d[4:24, 12:32, 5:25] + 30
 
 # seeds
@@ -348,8 +329,8 @@ and background")
         # oseg.make_gc()
 # manual seeds setting
 
-        # from PyQt4.QtGui import QApplication
-        # app = QApplication(sys.argv)
+        from PyQt4.QtGui import QApplication
+        app = QApplication(sys.argv)
         # oseg.interactivity()
         oseg.ninteractivity()
 
@@ -358,7 +339,7 @@ and background")
         # import pdb; pdb.set_trace()
 
         # mel by to být litr. tedy milion mm3
-        self.assertGreater(volume, 900000)
+        self.assertGreater(volume, 800000)
         self.assertLess(volume, 1100000)
 
     def test_volume_resize(self):
@@ -406,8 +387,7 @@ and background")
         """
         Function uses organ_segmentation object for segmentation
         """
-        dcmdir = os.path.join(
-            lisa.dataset.sample_data_path(),
+        dcmdir = io3d.datasets.join_path(
             'matlab/examples/sample_data/DICOM/digest_article/'
             # path_to_script,
             # './../sample_data/matlab/examples/sample_data/DICOM/digest_article/'
@@ -451,16 +431,13 @@ and background")
         """
         Test dicomread module and graphcut module
         """
-        try:
-            from pysegbase import pycut
-        except:
-            print("Deprecated of pyseg_base as submodule")
-            import pycut
+        from imcut import pycut
 
+        path_to_script = os.path.dirname(os.path.abspath(__file__))
         dcmdir = os.path.join(path_to_script, './../sample_data/matlab/examples/sample_data/DICOM/digest_article/') #noqa
         data3d, metadata = dcmr.dcm_read_from_dir(dcmdir)
 
-        # print ("Data size: " + str(data3d.nbytes) + ', shape: ' + str(data3d.shape) ) #noqa
+        # print("Data size: " + str(data3d.nbytes) + ', shape: ' + str(data3d.shape) ) #noqa
 
         igc = pycut.ImageGraphCut(data3d, zoom=0.5)
         seeds = igc.seeds
@@ -476,5 +453,39 @@ and background")
         self.assertTrue(np.sum(segmentation == 0) > 100)
         # igc.show_segmentation()
 
+    def test_resize_data_one_value(self):
+        datap = io3d.datasets.generate_abdominal()
+        target_voxelsize_mm = 3
+        oseg = organ_segmentation.OrganSegmentation(
+                                                    working_voxelsize_mm=4,
+                                                    manualroi=False)
+        oseg.import_dataplus(dataplus=datap)
+        orig_shape = oseg.data3d.shape
+
+        oseg.resize_to_mm(target_voxelsize_mm)
+        self.assertEqual(oseg.voxelsize_mm[0], target_voxelsize_mm)
+        self.assertEqual(oseg.voxelsize_mm[1], target_voxelsize_mm)
+        self.assertEqual(oseg.voxelsize_mm[2], target_voxelsize_mm)
+        self.assertNotEqual(orig_shape[0], oseg.data3d.shape[0])
+        self.assertNotEqual(orig_shape[1], oseg.data3d.shape[1])
+        self.assertNotEqual(orig_shape[2], oseg.data3d.shape[2])
+
+    def test_resize_data_three_values(self):
+        datap = io3d.datasets.generate_abdominal()
+        target_voxelsize_mm = [7.14, 4.1, 3]
+        oseg = organ_segmentation.OrganSegmentation(
+            working_voxelsize_mm=4,
+            manualroi=False)
+        oseg.import_dataplus(dataplus=datap)
+        orig_shape = oseg.data3d.shape
+
+        oseg.resize_to_mm(target_voxelsize_mm)
+        self.assertEqual(oseg.voxelsize_mm[0], target_voxelsize_mm[0])
+        self.assertEqual(oseg.voxelsize_mm[1], target_voxelsize_mm[1])
+        self.assertEqual(oseg.voxelsize_mm[2], target_voxelsize_mm[2])
+        self.assertNotEqual(orig_shape[0], oseg.data3d.shape[0])
+        self.assertNotEqual(orig_shape[1], oseg.data3d.shape[1])
+        self.assertNotEqual(orig_shape[2], oseg.data3d.shape[2])
+
 if __name__ == "__main__":
     unittest.main()
