@@ -8,8 +8,8 @@ sys.path.append(os.path.join(path_to_script, "../extern/sed3/"))
 sys.path.append(os.path.join(path_to_script, "../src/"))
 import numpy as np
 
-import organ_segmentation
-import pysegbase.dcmreaddata as dcmr
+from lisa import organ_segmentation
+import imcut.dcmreaddata as dcmr
 import os.path
 
 
