@@ -5,6 +5,7 @@
 # import funkcí z jiného adresáře
 import os.path
 
+import sys
 path_to_script = os.path.dirname(os.path.abspath(__file__))
 # sys.path.append(os.path.join(path_to_script, "../extern/pyseg_base/src/"))
 # sys.path.append(os.path.join(path_to_script, "../extern/sed3/"))
@@ -14,8 +15,8 @@ import unittest
 from nose.plugins.attrib import attr
 import numpy as np
 
-# from PyQt4.QtGui import QApplication
-# import sed3
+from PyQt4.QtGui import QApplication
+import sed3
 
 from lisa import organ_segmentation
 from imtools import segmentation
@@ -32,7 +33,7 @@ class VesselsSegmentationTest(unittest.TestCase):
 
     def synthetic_data(self):
         # data
-        slab = {'none': 0, 'liver': 1, 'porta': 2}
+        slab = {'none': 0, 'liver': 1, 'porta': 2, "hepatic_veins": 3}
         voxelsize_mm = np.array([1.0, 1.0, 1.2])
 
         segm = np.zeros([256, 256, 80], dtype=np.int16)
@@ -43,6 +44,7 @@ class VesselsSegmentationTest(unittest.TestCase):
         segm[120:130, 70:190, 40:45] = slab['porta']
         segm[80:130, 100:110, 40:45] = slab['porta']
         segm[120:170, 130:135, 40:44] = slab['porta']
+        segm[150:160, 70:190, 51:55] = slab['hepatic_veins']
 
         data3d = np.zeros(segm.shape)
         data3d[segm == slab['liver']] = 156
@@ -53,7 +55,7 @@ class VesselsSegmentationTest(unittest.TestCase):
 
     def test_synthetic_data_segmentation(self):
         """
-        Function uses organ_segmentation  for synthetic box object
+        Function uses organ_segmentation for synthetic box object
         segmentation.
         """
 
@@ -75,7 +77,7 @@ class VesselsSegmentationTest(unittest.TestCase):
             voxelsize_mm=voxelsize_mm,
             threshold=180,
             inputSigma=0.15,
-            dilationIterations=2,
+            aoi_dilation_iterations=2,
             nObj=1,
             interactivity=False,
             biggestObjects=True,
@@ -133,20 +135,63 @@ class VesselsSegmentationTest(unittest.TestCase):
         self.assertGreater(ratio, 0.17)
         self.assertLess(ratio, 0.19)
 
+    def test_split_by_two_vessels(self):
+        """
+        Make virtual resection on synthetic data
+        """
+        import lisa.virtual_resection as vr
+        data3d, segm, voxelsize_mm, slab = self.synthetic_data()
+        seeds = np.zeros([256, 256, 80], dtype=np.int16)
+        seeds[125, 160, 44] = 1
+        datap = {'data3d': data3d, 'segmentation': segm,
+                 'voxelsize_mm': voxelsize_mm, 'slab': slab}
+
+        oseg = organ_segmentation.OrganSegmentation()
+        oseg.import_dataplus(datap)
+
+        oseg.split_organ_by_two_vessels(
+            seed_label1="porta",
+            seed_label2="hepatic_veins",
+            organ_label="liver",
+            output_label1="liver",
+            output_label2="liver_remnant"
+        )
+
+        resected = np.sum(
+            datap['segmentation'] == datap['slab']['liver'])
+        remaining = np.sum(
+            datap['segmentation'] == datap['slab']['liver_remnant'])
+        ratio = np.double(resected)/(resected+remaining)
+        # ed = sed3.sed3(datap["segmentation"])
+        # ed.show()
+        # print(ratio)
+
+        self.assertGreater(ratio, 0.6)
+        self.assertLess(ratio, 0.8)
+
     @attr('slow')
     def test_real_data_segmentation(self):
+        import lisa.dataset
+        app = QApplication(sys.argv)
 
-        dcmdir = os.path.join(path_to_script, './../sample_data/jatra_5mm')
+        dcmdir = os.path.join(lisa.dataset.sample_data_path(), 'jatra_5mm')
 
         oseg = organ_segmentation.OrganSegmentation(dcmdir,
                                                     working_voxelsize_mm=4)
-        oseg.add_seeds_mm([120], [120], [-81],
+        oseg.add_seeds_mm([81], [120], [120],
                           label=1, radius=30)
-        oseg.add_seeds_mm([170, 220, 250], [250, 250, 200], [-81],
+        oseg.add_seeds_mm([81], [170, 220, 250], [250, 250, 200],
                           label=2, radius=30)
+        oseg.add_seeds_mm([100], [170], [140],
+                          label=10, radius=5)
         # oseg.interactivity(min_val=-200, max_val=200)
         oseg.ninteractivity()
 
+        ed = sed3.sed3(oseg.data3d, contour=oseg.segmentation, seeds=oseg.seeds)
+        ed.show()
+
+        oseg.portalVeinSegmentation(seeds=(oseg.seeds==10))
+
 #
 #
 #        outputTmp = segmentation.vesselSegmentation(
@@ -164,5 +209,30 @@ class VesselsSegmentationTest(unittest.TestCase):
 #
 #
 
+    @attr('interactive')
+    def test_ui_threshold_same_params_as_portal_segmentation(self):
+
+        params = {
+            'threshold': -1,
+            'inputSigma': 0.15,
+            'dilationIterations': 10,
+            'nObj': 1,
+            'biggestObjects': False,
+            'useSeedsOfCompactObjects': True,
+            'interactivity': True,
+            'binaryClosingIterations': 2,
+            'binaryOpeningIterations': 0
+        }
+        import imtools
+        import imtools.sample_data
+        datap = imtools.sample_data.generate()
+        app = QApplication(sys.argv)
+        outputTmp = segmentation.vesselSegmentation(
+            datap['data3d'],
+            datap['segmentation'],
+            # datap['voxelsize_mm'],
+            **params)
+        # uit.run()
+        # plt.show()
 if __name__ == "__main__":
     unittest.main()
